@@ -18,7 +18,7 @@ from .launchers.launch_sca_scanner import run_sca_scanner
 from .launchers.docker_util import get_formated_timestamp, create_skenoutput_folder, delete_skenoutput_folder
 
 SKEN_SERVER_BASE_URL = 'https://cli.sken.ai/api/cli/v1'
-#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1/test2'
+#SKEN_SERVER_BASE_URL = 'http://localhost:8080/api/cli/v1'
 LANGUAGES = ['ruby', 'javascript', 'typescript', 'python', 'php',
              'java', 'nodejs', 'license', 'go', 'python2']
 SCANNERS = ['sast', 'dast', 'sca', 'secrets']
@@ -114,9 +114,13 @@ def precheck():
         print('Please specify "appid" in sken.yaml or use --app_id flag.')
         exit(0)
 
+    # If the scanner param is not specified in the yaml, default to ALL.
     if not 'scanner' in sken_config or sken_config['scanner'] is None:
-        print('Please specify "scanner" in sken.yaml or use --scanner flag.')
-        exit(0)
+        sken_config['scanner'] = 'sast,secrets,sca'
+    
+    # run dast if DAST_URL is specified
+    if 'DAST_URL' in sken_config['variables'] and sken_config['variables']['DAST_URL'] is not None and not 'dast' in sken_config['scanner'] :
+        sken_config['scanner'] = sken_config['scanner'] + ',dast'
 
     global config
     config = sken_config
@@ -170,9 +174,15 @@ def run_scan(scanner_type, scan_config):
 
         timing_file = generate_scan_result_file(scan_config['build_dir'], scan_start, scan_end)
 
+        timestamp = upload_output(out_file, timing_file)
+        fileEmpty = False
         if os.path.exists(out_file):
-            timestamp = upload_output(out_file, timing_file)
-            trigger_etl(timestamp, ntpath.basename(out_file), scan_config['scanner'], os.path.getsize(out_file) <= 0)
+            fileEmpty = os.path.getsize(out_file) <= 0
+        else:
+            fileEmpty = True
+
+        trigger_etl(timestamp, ntpath.basename(out_file), scan_config['scanner'], fileEmpty)
+
     except Exception as e:
         global scan_error_occurred
         scan_error_occurred = True
@@ -229,14 +239,12 @@ def run_sast(p_code_lang=None):
                 scanners = 'gosec'
             elif code_lang == 'python2':
                 if sys.version_info >= (3, 0):
-                    print('Incompatible Python versions. Version 3 installed but Version 2 of Bandit requested.')
-                    continue
+                    print('Warning: possible incompatibility with Python versions. Version 3 installed but Version 2 of Bandit requested.')
 
                 scanners = 'banditpy2'
             elif code_lang == 'python':
                 if sys.version_info < (3, 0):
-                    print('Incompatible Python versions. Version 2 installed but Version 3 of Bandit requested.')
-                    continue
+                    print('Warning: possible incompatibility with Python versions. Version 2 installed but Version 3 of Bandit requested.')
 
                 scanners = 'banditpy3'
             elif code_lang == 'java':
@@ -284,9 +292,10 @@ def upload_output(output_file, timing_file):
             region_name=scan_info['awsRegion'])
 
         s3 = session.resource('s3')
-        file_name = ntpath.basename(output_file)
-        data = open(output_file, 'rb')
-        s3.Bucket('sken-scanner-output').put_object(Key=config['appid'] + '/' + timestamp + '/' + file_name, Body=data)
+        if os.path.exists(output_file):
+            file_name = ntpath.basename(output_file)
+            data = open(output_file, 'rb')
+            s3.Bucket('sken-scanner-output').put_object(Key=config['appid'] + '/' + timestamp + '/' + file_name, Body=data)
         
         file_name = ntpath.basename(timing_file)
         data = open(timing_file, 'rb')
@@ -299,9 +308,11 @@ def upload_output(output_file, timing_file):
 
 def trigger_etl(timestamp, fileName, scanner, output_empty):
     print('ETL started')
+    resp_text = ''
     try:
         payload = {'appId': config['appid'], 'apiId': config['apiid'], 'timestamp': timestamp, 'fileName': fileName, 'scanner': scanner, 'fileEmpty': output_empty}
         resp = requests.get(SKEN_SERVER_BASE_URL + "/doETL", params=payload)
+        resp_text = resp.text
         etl_result = resp.json()
 
         if not etl_result['success']:
@@ -310,10 +321,10 @@ def trigger_etl(timestamp, fileName, scanner, output_empty):
 
         print('ETL Succeeded')
     except Exception as e:
-        print('Failed to trigger ETL: ' + str(e))
+        print('Failed to trigger ETL: ' + str(e) + ', response: ' + resp_text)
 
 def version():
-    return '0.1.47'
+    return '0.1.49'
 
 def main():
     parser = argparse.ArgumentParser(description='Sken Runner.')
